TimPushPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • TimPushPlatform
Implementers

Constructors

TimPushPlatform()
Constructs a TimPushPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPushListener({required TimPushListener listener}) Future<TimPushResult<void>>
disablePostNotificationInForeground({required bool disable}) Future<TimPushResult<void>>
forceUseFCMPushChannel({required bool enable}) Future<TimPushResult<void>>
getRegistrationID() Future<TimPushResult<String>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerPush({int? sdkAppId, String? appKey, int? businessId}) Future<TimPushResult<void>>
removePushListener({required TimPushListener listener}) Future<TimPushResult<void>>
setRegistrationID({required String registrationID}) Future<TimPushResult<void>>
toString() String
A string representation of this object.
inherited
unRegisterPush() Future<TimPushResult<void>>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance TimPushPlatform
The default instance of TimPushPlatform to use.
getter/setter pair