MethodChannelTimPush class

An implementation of TimPushPlatform that uses method channels.

Inheritance

Constructors

MethodChannelTimPush()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPushListener({required TimPushListener listener}) Future<TimPushResult<void>>
override
disablePostNotificationInForeground({required bool disable}) Future<TimPushResult<void>>
override
forceUseFCMPushChannel({required bool enable}) Future<TimPushResult<void>>
override
getRegistrationID() Future<TimPushResult<String>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerPush({int? sdkAppId, String? appKey, int? businessId}) Future<TimPushResult<void>>
override
removePushListener({required TimPushListener listener}) Future<TimPushResult<void>>
override
setRegistrationID({required String registrationID}) Future<TimPushResult<void>>
override
toString() String
A string representation of this object.
inherited
unRegisterPush() Future<TimPushResult<void>>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited